@@ -10,17 +10,13 @@ def card_reference_role(role, rawtext, text, lineno, inliner,
     except:
         wikiid, rest = text, text
     context = inliner.document.settings.context
-    cardrset = context._cw.execute('Card X WHERE X wikiid %(id)s',
-                                   {'id': wikiid})
-    if cardrset:
-        ref = cardrset.get_entity(0, 0).absolute_url()
-    else:
-        schema = context._cw.vreg.schema
-        if schema.eschema('Card').has_perm(context._cw, 'add'):
-            ref = context._cw.build_url('view', vid='creation', etype='Card', wikiid=wikiid)
-        else:
-            ref = '#'
+    ref = context._cw.build_url('card/' + wikiid)
+    rset = context._cw.execute('Card C WHERE C wikiid %(w)s', {'w': wikiid})
     set_classes(options)
+    if not rset:
+        options['classes'] = ['doesnotexist']
+    else:
+        options.pop('classes', None)
     return [nodes.reference(rawtext, utils.unescape(rest), refuri=ref,
                             **options)], []
 
